/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Component, Input, OnInit } from "@angular/core";
import { CapabilityRequest } from "../../../../model/capability-request";
import { Capability } from "../../../../model/capability";
import {CapabilityVersion} from "../../../../model/capability-version";
import {WorkflowService} from "../../../../services/workflow.service";
import {CapabilityRequestService} from "../../../../services/capability-request.service";
import { JsonObject } from "@angular/compiler-cli/ngcc/src/packages/entry_point";

@Component({
  selector: "app-capability-data-access",
  templateUrl: "./capability-data-access.component.html",
  styleUrls: ["./capability-data-access.component.scss"],
})
export class CapabilityDataAccessComponent implements OnInit {
  @Input() capabilityRequest: CapabilityRequest;
  @Input() capability: Capability;
  @Input() currentVersion: CapabilityVersion;

  public qaNotes: string;

  constructor(
    private workflowService: WorkflowService,
    private capabilityRequestService: CapabilityRequestService,
  ) {
  }

  ngOnInit(): void {
  }

  // Observer for capability objects
  private qaObserver = {
    next: (capability) => {
      this.capability = capability;
      if (!this.qaNotes && this.shouldHaveWeblog() && this.currentVersion.current_execution) {
        this.getQaNotesURL();
      }
    },
    error: (error) => console.error("Error when retrieving capability:" + error),
  };

  private saveQaNotesObserver = {
    next: () => {
    },
    error: (error) => console.error("Error when saving QA notes edit:", error),
  };

  // Get qa_notes.html contents for editing
  private async getQaNotesURL() {
    var curCapabilityName = this.capability.name;
    var curCapabilityRequestId = this.currentVersion.current_execution.current_workflow_request_id;
    this.qaNotes = await new Promise<string>(resolve =>
      this.workflowService.retrieveQaNotes(curCapabilityName, curCapabilityRequestId)
        .subscribe(notes => resolve(notes['resp'])));
  }

  emitEditEventToParent(edits: string): void {
    var curCapabilityName = this.capability.name;
    var curCapabilityRequestId = this.currentVersion.current_execution.current_workflow_request_id;
    this.workflowService.saveQaNotes(curCapabilityName, curCapabilityRequestId, edits)
      .subscribe(this.saveQaNotesObserver);
    this.getQaNotesURL();
  }

  /**
   * Do we expect current version of capability request to have a weblog?
   *
   @return true if current version's capability and state imply it should have a weblog
   */
  shouldHaveWeblog(): boolean {
    if (!this.capability || !this.currentVersion.current_execution.state_name) {
      return false;
    }

    const request = this.capabilityRequest;
    const version = this.currentVersion;
    const names = ["std_calibration", "std_cms_imaging", "restore_cms", "std_restore_imaging"];
    const states = ["Awaiting QA", "AoD Review", "Complete", "Failed", "QA Closed"];

    if (states.includes(version.current_execution.state_name)) {
      return names.includes(request.capability_name);
    }

    return false;
  }

  /**
   * Do we expect current version of capability request to have downloadable products?
   *
   @return true if current version's capability and state imply it should be downloadable
   */
  shouldHaveDownload(): boolean {
    if (!this.capability || !this.currentVersion.current_execution.state_name) {
      return false;
    }

    const request = this.capabilityRequest;
    const version = this.currentVersion;
    const names = ["test_download", "restore_cms", "std_restore_imaging"];
    const states = ["Complete"];

    if (states.includes(version.current_execution.state_name)) {
      return names.includes(request.capability_name);
    }

    return false;
  }
}
