#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
# -*- coding: utf-8 -*-
"""
An incomplete declarative base model of the legacy archive
Author:    Richard Falardeau <rfalarde@nrao.edu>
"""
from sqlalchemy import (
    CHAR,
    VARCHAR,
    Column,
    DateTime,
    Float,
    Index,
    Integer,
    Numeric,
    String,
    Table,
    text,
)
from sqlalchemy.dialects.oracle import NUMBER
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.sql.sqltypes import NullType

# pylint: disable=invalid-name
Base = declarative_base()
metadata = Base.metadata


# pylint: disable=too-few-public-methods
class LegacyProject(Base):
    r"""The model of the project table in the legacy db"""
    __tablename__ = "project"

    project_code = Column(String(16), primary_key=True)
    observer = Column(String(48))
    observer_id = Column(Numeric)
    starttime = Column(Numeric, primary_key=True)
    stoptime = Column(Numeric, primary_key=True)
    proprietary = Column(Numeric)
    telescope = Column(String(12))
    telescope_config = Column(String(36))
    obs_bands = Column(String(24))
    total_obs_time = Column(Numeric)
    num_segments = Column(Numeric)
    arch_files = Column(Numeric)
    row_date = Column(Numeric)
    raw_project_code = Column(String(16))
    project_lock = Column(String(8))
    unlock_expire = Column(Numeric)
    grant_access = Column(String(12))
    proprietary_duration = Column(Numeric)
    warned = Column(Numeric)
    project_id = Column(Numeric)

    def __repr__(self):
        r"""Return the string representation of this class.

        :return: The string representation of self.
        """
        repr_str_list = ["{c}("]
        temp = ["{0}={{s.{0}}}".format(key) for key in vars(self) if not key.startswith("_")]
        self_list = ", ".join(temp)
        repr_str_list.append(self_list)
        repr_str_list.append(")")

        return "".join(repr_str_list).format(c=self.__class__.__name__, s=self)


t_afl_safe = Table(
    "afl_safe",
    metadata,
    Column("site_code", VARCHAR(8), nullable=False),
    Column("arch_file_id", NUMBER(asdecimal=False), nullable=False),
    Column("root_directory", VARCHAR(128), nullable=False),
    Column("arch_file", VARCHAR(128), nullable=False),
    Column("mimetype", VARCHAR(80)),
    Column("common_file_id", VARCHAR(64)),
    Column("ngas_host", VARCHAR(64)),
    schema="E2EMGR",
)


class Alia(Base):
    __tablename__ = "alias"
    __table_args__ = {"schema": "E2EMGR"}

    source_id = Column(VARCHAR(12), server_default=text("' '"))
    jsource_id = Column(VARCHAR(12), nullable=False)
    prog_code = Column(VARCHAR(8), server_default=text("' '"))
    pk = Column(Integer, primary_key=True)


t_alltables_columns = Table(
    "alltables_columns",
    metadata,
    Column("column_name", VARCHAR(32), nullable=False, index=True),
    Column("table_name", VARCHAR(256), nullable=False),
    Column("description", VARCHAR(128), nullable=False),
    Column("unit", VARCHAR(16), nullable=False),
    Column("ucd", VARCHAR(64), nullable=False),
    Column("utype", VARCHAR(64), nullable=False),
    Column("datatype", VARCHAR(32), nullable=False),
    Column("varsize", NUMBER(asdecimal=False), nullable=False),
    Column("primary", VARCHAR(16), nullable=False),
    Column("indexed", VARCHAR(16), nullable=False),
    Column("std", VARCHAR(16), nullable=False),
    Column("catagory", VARCHAR(32), nullable=False),
    Column("example", VARCHAR(128), nullable=False),
    schema="E2EMGR",
)


t_antenna = Table(
    "antenna",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False),
    Column("segment", VARCHAR(4), nullable=False),
    Column("arch_file_id", NUMBER(asdecimal=False), nullable=False),
    Column("antenna_id", NUMBER(asdecimal=False), nullable=False),
    Column("name", VARCHAR(12), nullable=False),
    Column("station", VARCHAR(18), nullable=False),
    Column("mount", VARCHAR(8), nullable=False),
    Column("dish_diameter", NUMBER(asdecimal=False), nullable=False),
    Column("antenna_type", VARCHAR(14), nullable=False),
    Column("axis_off", NUMBER(asdecimal=False), nullable=False),
    Column("frame", VARCHAR(12), nullable=False),
    Index("antenna_idx", "project_code", "arch_file_id", "antenna_id"),
    schema="E2EMGR",
)


t_archfileloc_ngas_migration = Table(
    "archfileloc_ngas_migration",
    metadata,
    Column("site_code", VARCHAR(8), nullable=False),
    Column("arch_file_id", NUMBER(asdecimal=False), nullable=False),
    Column("root_directory", VARCHAR(128), nullable=False),
    Column("arch_file", VARCHAR(128), nullable=False),
    Column("mimetype", VARCHAR(80)),
    Column("common_file_id", VARCHAR(64)),
    Column("ngas_host", VARCHAR(64)),
    schema="E2EMGR",
)


t_archfilelocation = Table(
    "archfilelocation",
    metadata,
    Column("site_code", VARCHAR(8), nullable=False, index=True),
    Column("arch_file_id", NUMBER(asdecimal=False), nullable=False),
    Column("root_directory", VARCHAR(128), nullable=False),
    Column("arch_file", VARCHAR(128), nullable=False, index=True),
    Column("mimetype", VARCHAR(80)),
    Column("common_file_id", VARCHAR(64)),
    Column("ngas_host", VARCHAR(64)),
    schema="E2EMGR",
)


t_archfilelocationgbt = Table(
    "archfilelocationgbt",
    metadata,
    Column("site_code", VARCHAR(8), nullable=False),
    Column("arch_file_id", NUMBER(asdecimal=False), nullable=False),
    Column("root_directory", VARCHAR(128), nullable=False),
    Column("arch_file", VARCHAR(128), nullable=False),
    Column("mimetype", VARCHAR(80)),
    Column("common_file_id", VARCHAR(64)),
    Column("ngas_host", VARCHAR(64)),
    schema="E2EMGR",
)


t_archive = Table(
    "archive",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False, index=True),
    Column("segment", VARCHAR(4), nullable=False),
    Column("starttime", NUMBER(asdecimal=False), nullable=False),
    Column("stoptime", NUMBER(asdecimal=False), nullable=False),
    Column("telescope", VARCHAR(12), nullable=False),
    Column("telescope_config", VARCHAR(8), nullable=False),
    Column("arch_format", VARCHAR(8), nullable=False),
    Column("data_type", VARCHAR(12), nullable=False),
    Column("subarray_id", NUMBER(asdecimal=False), nullable=False),
    Column("arch_file_id", NUMBER(asdecimal=False), nullable=False, index=True),
    Column("arch_file", VARCHAR(128), nullable=False, index=True),
    Column("arch_file_date", NUMBER(asdecimal=False), nullable=False),
    Column("catalog_date", NUMBER(asdecimal=False), nullable=False),
    Column("file_size", NUMBER(asdecimal=False), nullable=False),
    Column("raw_project_code", VARCHAR(16), nullable=False, index=True),
    Column("annex1_id", NUMBER(asdecimal=False), nullable=False),
    Column("obs_bands", VARCHAR(24), nullable=False),
    Column("project_id", NUMBER(19, 0, False), server_default=text("0")),
    Column("sb_id", NUMBER(19, 0, False), server_default=text("0")),
    Column("eb_id", NUMBER(19, 0, False), server_default=text("0")),
    Column("datamsg", VARCHAR(128), server_default=text("'none'")),
    Column("datalevel", NUMBER(8, 0, False), server_default=text("0")),
    Column("sb_type", VARCHAR(32), server_default=text("'none'")),
    Index("archive3_idx", "starttime", "stoptime"),
    schema="E2EMGR",
)


t_archivegbt = Table(
    "archivegbt",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False),
    Column("segment", VARCHAR(4), nullable=False),
    Column("starttime", NUMBER(asdecimal=False), nullable=False),
    Column("stoptime", NUMBER(asdecimal=False), nullable=False),
    Column("telescope", VARCHAR(12), nullable=False),
    Column("telescope_config", VARCHAR(8), nullable=False),
    Column("arch_format", VARCHAR(8), nullable=False),
    Column("data_type", VARCHAR(12), nullable=False),
    Column("subarray_id", NUMBER(asdecimal=False), nullable=False),
    Column("arch_file_id", NUMBER(asdecimal=False), nullable=False),
    Column("arch_file", VARCHAR(128), nullable=False),
    Column("arch_file_date", NUMBER(asdecimal=False), nullable=False),
    Column("catalog_date", NUMBER(asdecimal=False), nullable=False),
    Column("file_size", NUMBER(asdecimal=False), nullable=False),
    Column("raw_project_code", VARCHAR(16), nullable=False),
    Column("annex1_id", NUMBER(asdecimal=False), nullable=False),
    Column("obs_bands", VARCHAR(16), nullable=False),
    Column("project_id", NUMBER(19, 0, False), server_default=text("0")),
    Column("sb_id", NUMBER(19, 0, False), server_default=text("0")),
    Column(
        "eb_id",
        NUMBER(19, 0, False),
        server_default=text(
            """\
0
"""
        ),
    ),
    Column("datamsg", VARCHAR(128), server_default=text("'none'")),
    Column("datalevel", NUMBER(8, 0, False), server_default=text("0")),
    Column("sb_type", VARCHAR(32), nullable=False, server_default=text("'none' ")),
    schema="E2EMGR",
)


t_archivegbtold = Table(
    "archivegbtold",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False),
    Column("segment", VARCHAR(4), nullable=False),
    Column("starttime", NUMBER(asdecimal=False), nullable=False),
    Column("stoptime", NUMBER(asdecimal=False), nullable=False),
    Column("telescope", VARCHAR(12), nullable=False),
    Column("telescope_config", VARCHAR(8), nullable=False),
    Column("arch_format", VARCHAR(8), nullable=False),
    Column("data_type", VARCHAR(12), nullable=False),
    Column("subarray_id", NUMBER(asdecimal=False), nullable=False),
    Column("arch_file_id", NUMBER(asdecimal=False), nullable=False),
    Column("arch_file", VARCHAR(128), nullable=False),
    Column("arch_file_date", NUMBER(asdecimal=False), nullable=False),
    Column("catalog_date", NUMBER(asdecimal=False), nullable=False),
    Column("file_size", NUMBER(asdecimal=False), nullable=False),
    Column("raw_project_code", VARCHAR(16), nullable=False),
    Column("annex1_id", NUMBER(asdecimal=False), nullable=False),
    Column("obs_bands", VARCHAR(16), nullable=False),
    Column("project_id", NUMBER(19, 0, False), server_default=text("0")),
    Column("sb_id", NUMBER(19, 0, False), server_default=text("0")),
    Column("eb_id", NUMBER(19, 0, False), server_default=text("0")),
    Column("datamsg", VARCHAR(128), server_default=text("'none'")),
    Column("datalevel", NUMBER(8, 0, False), server_default=text("0")),
    Column(
        "sb_type",
        VARCHAR(32),
        server_default=text(
            """\
'none'
"""
        ),
    ),
    schema="E2EMGR",
)


t_archivesites = Table(
    "archivesites",
    metadata,
    Column("site_code", VARCHAR(8), nullable=False, index=True),
    Column("host", VARCHAR(24), nullable=False),
    Column("root_directory", VARCHAR(64), nullable=False),
    Column("ftp_directory", VARCHAR(64), nullable=False),
    Column("site_name", VARCHAR(64), nullable=False),
    schema="E2EMGR",
)


t_archvla = Table(
    "archvla",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False),
    Column("telescope", VARCHAR(12), nullable=False),
    Column("telescope_config", VARCHAR(8), nullable=False),
    Column("starttime", NUMBER(asdecimal=False), nullable=False),
    Column("stoptime", NUMBER(asdecimal=False), nullable=False),
    schema="E2EMGR",
)


t_asa_columns = Table(
    "asa_columns",
    metadata,
    Column("column_name", VARCHAR(32), index=True, server_default=text("'none'")),
    Column("table_name", VARCHAR(32), server_default=text("'none'")),
    Column("description", VARCHAR(64), server_default=text("'none'")),
    Column("unit", VARCHAR(16), server_default=text("'none'")),
    Column("ucd", VARCHAR(64), server_default=text("'none'")),
    Column("utype", VARCHAR(64), server_default=text("'none'")),
    Column("datatype", VARCHAR(32), server_default=text("'none'")),
    Column("varsize", NUMBER(asdecimal=False), server_default=text("0")),
    Column("primary", VARCHAR(16), server_default=text("'none'")),
    Column("indexed", VARCHAR(16), server_default=text("'none'")),
    Column("std", VARCHAR(16), server_default=text("'none'")),
    Column("tooltip", VARCHAR(128), server_default=text("'none'")),
    Column(
        "examples",
        VARCHAR(128),
        server_default=text(
            """\
'none'
"""
        ),
    ),
    schema="E2EMGR",
)


t_asa_project = Table(
    "asa_project",
    metadata,
    Column("project_code", VARCHAR(64), server_default=text("'none'")),
    Column("project_uid", VARCHAR(64), server_default=text("'none'")),
    Column("proposal_uid", VARCHAR(64), server_default=text("'none'")),
    Column("pi_name", VARCHAR(64), server_default=text("'none'")),
    Column("pi_id", VARCHAR(64), server_default=text("'none'")),
    Column("coi_name", VARCHAR(64), server_default=text("'none'")),
    Column("title", VARCHAR(64), server_default=text("'none'")),
    Column("type", VARCHAR(64), server_default=text("'none'")),
    Column("associated_arc", VARCHAR(64), server_default=text("'none'")),
    Column("proposal_cycle", VARCHAR(64), server_default=text("'none'")),
    Column("proposal_abstract", VARCHAR(64), server_default=text("'none'")),
    Column("proposed_start_date", VARCHAR(64), server_default=text("'none'")),
    Column("proposed_end_date", VARCHAR(64), server_default=text("'none'")),
    Column("first_obs_start", VARCHAR(64), server_default=text("'none'")),
    Column("first_obs_end", VARCHAR(64), server_default=text("'none'")),
    Column("last_obs_start", VARCHAR(64), server_default=text("'none'")),
    Column("last_obs_end", VARCHAR(64), server_default=text("'none'")),
    Column(
        "arc_release",
        VARCHAR(64),
        server_default=text(
            """\
'none'
"""
        ),
    ),
    schema="E2EMGR",
)


t_asa_projects = Table(
    "asa_projects",
    metadata,
    Column("project_code", VARCHAR(64), server_default=text("'none'")),
    Column("project_uid", VARCHAR(64), server_default=text("'none'")),
    Column("proposal_uid", VARCHAR(64), server_default=text("'none'")),
    Column("pi_name", VARCHAR(64), server_default=text("'none'")),
    Column("pi_id", VARCHAR(64), server_default=text("'none'")),
    Column("coi_name", VARCHAR(64), server_default=text("'none'")),
    Column("title", VARCHAR(64), server_default=text("'none'")),
    Column("type", VARCHAR(64), server_default=text("'none'")),
    Column("associated_arc", VARCHAR(64), server_default=text("'none'")),
    Column("proposal_cycle", VARCHAR(64), server_default=text("'none'")),
    Column("proposal_abstract", VARCHAR(64), server_default=text("'none'")),
    Column("proposed_start_date", VARCHAR(64), server_default=text("'none'")),
    Column("proposed_end_date", VARCHAR(64), server_default=text("'none'")),
    Column("first_obs_start", VARCHAR(64), server_default=text("'none'")),
    Column("first_obs_end", VARCHAR(64), server_default=text("'none'")),
    Column("last_obs_start", VARCHAR(64), server_default=text("'none'")),
    Column("last_obs_end", VARCHAR(64), server_default=text("'none'")),
    Column(
        "arc_release",
        VARCHAR(64),
        server_default=text(
            """\
'none'
"""
        ),
    ),
    schema="E2EMGR",
)


t_asa_science = Table(
    "asa_science",
    metadata,
    Column("dataset_id", VARCHAR(64), server_default=text("'none'")),
    Column("asdm_uid", VARCHAR(64), server_default=text("'none'")),
    Column("field_uid", VARCHAR(64), server_default=text("'none'")),
    Column("spectral_window_uid", VARCHAR(64), server_default=text("'none'")),
    Column("project_uid", VARCHAR(64), server_default=text("'none'")),
    Column("schedblock_uid", VARCHAR(64), server_default=text("'none'")),
    Column("execblock_uid", VARCHAR(64), server_default=text("'none'")),
    Column("ra", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("dec", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("ra_source", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("dec_source", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("cx", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("cy", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("cz", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("az_min", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("az_max", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("elevation_min", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("elevation_max", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("wcs_cd1_1", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("wcs_cd1_2", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("wcs_cd2_1", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("wcs_cd2_2", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("wcs_crpix1", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("wcs_crpix2", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("wcs_crval1", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("wcs_crval2", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("spatial_scale_min", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("spatial_scale_max", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("gal_longitude", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("gal_latitude", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("ecliptic_longitude", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("ecliptic_latitude", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("footprint", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("fov", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("bounding_box", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("source_name", VARCHAR(64), server_default=text("'none'")),
    Column("source_is_in_simbad", VARCHAR(64), server_default=text("'none'")),
    Column("source_class", VARCHAR(64), server_default=text("'none'")),
    Column("source_redshift", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("source_alma_catalog_id", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("start_date", VARCHAR(64), server_default=text("'none'")),
    Column("end_date", VARCHAR(64), server_default=text("'none'")),
    Column("int_time", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("time_resolution", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("frequency", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("frequency_max", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("frequency_min", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("frequency_resolution", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("bandwidth", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("rest_frequency", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("rest_frequency_min", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("rest_frequency_max", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("rest_frequency_resolution", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("rest_bandwidth", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("band", VARCHAR(64), server_default=text("'none'")),
    Column("frequency_support", VARCHAR(128), server_default=text("'none'")),
    Column("rest_frequency_support", VARCHAR(128), server_default=text("'none'")),
    Column("velocity_resolution", NUMBER(16, 10, True), server_default=text("0.0")),
    Column("resolving_power", NUMBER(16, 10, True), server_default=text("0.0")),
    Column("rest_velocity_resolution", NUMBER(16, 10, True), server_default=text("0.0")),
    Column("rest_resolving_power", NUMBER(16, 10, True), server_default=text("0.0")),
    Column("channel_num", VARCHAR(32), server_default=text("'none'")),
    Column("spectral_window_num", VARCHAR(32), server_default=text("'none'")),
    Column("continuum_window_num", VARCHAR(32), server_default=text("'none'")),
    Column("obs_unitset_id", VARCHAR(128), server_default=text("'none'")),
    Column("science_goal_ouss_id", VARCHAR(128), server_default=text("'none'")),
    Column("group_ouss_id", VARCHAR(128), server_default=text("'none'")),
    Column("member_ouss_id", VARCHAR(128), server_default=text("'none'")),
    Column("sensitivity", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("flux_min", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("flux_max", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("uv_coverage_param1", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("uv_coverage_param2", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("pol_num", NUMBER(16, 0, False), server_default=text("0")),
    Column("pol_products", VARCHAR(128), server_default=text("'none'")),
    Column("airmass", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("pwv", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("temperature", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("windspeed", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("winddirection", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("ant_num", NUMBER(16, 0, False), server_default=text("0")),
    Column("ant_aca_num", NUMBER(16, 0, False), server_default=text("0")),
    Column("ant_main_num", NUMBER(16, 0, False), server_default=text("0")),
    Column("antennas", VARCHAR(128), server_default=text("'none'")),
    Column("baseline_max", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("baseline_min", NUMBER(16, 0, False), server_default=text("0.0")),
    Column("scan_num", NUMBER(6, 0, False), server_default=text("0")),
    Column("project_code", VARCHAR(64), server_default=text("'none'")),
    Column("schedblock_name", VARCHAR(64), server_default=text("'none'")),
    Column("observation_category", VARCHAR(64), server_default=text("'none'")),
    Column("scan_intent", VARCHAR(64), server_default=text("'none'")),
    Column("access_format", VARCHAR(64), server_default=text("'none'")),
    Column(
        "processing_level",
        NUMBER(6, 0, False),
        server_default=text(
            """\
0
"""
        ),
    ),
    schema="E2EMGR",
)


t_calib_parm_pos = Table(
    "calib_parm_pos",
    metadata,
    Column("jsource_id", VARCHAR(10), nullable=False),
    Column("epoch", DateTime),
    Column("rarad", NUMBER(12, 8, True), server_default=text("0")),
    Column("decrad", NUMBER(12, 8, True), server_default=text("0")),
    Column("raerr", NUMBER(10, 8, True), server_default=text("0")),
    Column("decerr", NUMBER(10, 6, True), server_default=text("0")),
    Column("telescope", VARCHAR(5), nullable=False),
    Column("config", VARCHAR(5), server_default=text("' '")),
    Column("obs_freq", Float, server_default=text("0")),
    Column("freq_min", Float, server_default=text("0")),
    Column("freq_max", Float, server_default=text("0")),
    Column("uv_min", NUMBER(12, 6, True), server_default=text("0")),
    Column("uv_max", NUMBER(12, 6, True), server_default=text("0")),
    Column("flux", NUMBER(8, 4, True), server_default=text("0")),
    Column("resolution", NUMBER(6, 4, True), server_default=text("0")),
    Column("variability", NUMBER(6, 4, True), server_default=text("0")),
    Column("cdvlba", CHAR(2), server_default=text("' '")),
    Column("cd_vla", CHAR(2), server_default=text("' '")),
    Column("entry_date", DateTime),
    Column("parm_remarks", VARCHAR(64), server_default=text("' '")),
    schema="E2EMGR",
)


class CalibSrcPo(Base):
    __tablename__ = "calib_src_pos"
    __table_args__ = {"schema": "E2EMGR"}

    remarks = Column(VARCHAR(200), nullable=False)
    ssize = Column(NUMBER(10, 0, False), server_default=text("0"))
    flux = Column(NUMBER(10, 6, True), server_default=text("0"))
    mfreq = Column(NUMBER(asdecimal=False), server_default=text("0"))
    ufreq = Column(NUMBER(asdecimal=False), server_default=text("0"))
    lfreq = Column(NUMBER(asdecimal=False), server_default=text("0"))
    distance = Column(NUMBER(asdecimal=False), server_default=text("0"))
    ddec = Column(NUMBER(10, 6, True), server_default=text("0"))
    dra = Column(NUMBER(10, 6, True), server_default=text("0"))
    repoch = Column(DateTime)
    parallax = Column(NUMBER(8, 6, True), server_default=text("0"))
    decerr = Column(NUMBER(12, 8, True), server_default=text("0"))
    raerr = Column(NUMBER(12, 8, True), server_default=text("0"))
    decrad = Column(NUMBER(12, 8, True), server_default=text("0"))
    rarad = Column(NUMBER(12, 8, True), server_default=text("0"))
    epoch = Column(DateTime)
    calcode = Column(CHAR(6), server_default=text("' '"))
    prog_code = Column(VARCHAR(6), server_default=text("' '"))
    dqualifier = Column(Integer, server_default=text("0"))
    cqualifier = Column(Integer, server_default=text("0"))
    uqualifier = Column(Integer, server_default=text("0"))
    entrydate = Column(DateTime)
    jsource_id = Column(VARCHAR(12), nullable=False)
    pk = Column(Integer, primary_key=True)


t_config = Table(
    "config",
    metadata,
    Column("telescope", VARCHAR(12), nullable=False),
    Column("telescope_config", VARCHAR(8), nullable=False),
    Column("starttime", NUMBER(asdecimal=False), nullable=False),
    Column("stoptime", NUMBER(asdecimal=False), nullable=False),
    schema="E2EMGR",
)


t_datadesc = Table(
    "datadesc",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False, index=True),
    Column("segment", VARCHAR(4), nullable=False),
    Column("arch_file_id", NUMBER(asdecimal=False), nullable=False),
    Column("data_desc_id", NUMBER(asdecimal=False), nullable=False, index=True),
    Column("sub_desc_id", NUMBER(asdecimal=False), nullable=False, index=True),
    Column("if_band", VARCHAR(4), nullable=False),
    Column("if_ref_freq", NUMBER(asdecimal=False), nullable=False),
    Column("pol1", NUMBER(asdecimal=False), nullable=False),
    Column("pol2", NUMBER(asdecimal=False), nullable=False),
    Column("pol3", NUMBER(asdecimal=False), nullable=False),
    Column("pol4", NUMBER(asdecimal=False), nullable=False),
    Column("if_conv_chain", NUMBER(asdecimal=False), nullable=False),
    Column("sub_chan_id", NUMBER(asdecimal=False), nullable=False),
    Column("sub_ref_freq", NUMBER(asdecimal=False), nullable=False),
    Column("sub_bandw", NUMBER(asdecimal=False), nullable=False),
    Column("sub_pol1", NUMBER(asdecimal=False), nullable=False),
    Column("sub_pol2", NUMBER(asdecimal=False), nullable=False),
    Column("sub_pol3", NUMBER(asdecimal=False), nullable=False),
    Column("sub_pol4", NUMBER(asdecimal=False), nullable=False),
    Column("sub_net_sideband", NUMBER(asdecimal=False), nullable=False),
    Column("sub_num_chans", NUMBER(asdecimal=False), nullable=False),
    Column("corr_mode", VARCHAR(24)),
    Column("if_chan", VARCHAR(8)),
    Column(
        "backend_id",
        VARCHAR(24),
        server_default=text(
            """\
'none'
   """
        ),
    ),
    Column("receiver_id", VARCHAR(24), nullable=False, server_default=text("'none' ")),
    Column("veldef", VARCHAR(24), server_default=text("'none'")),
    Column("version", VARCHAR(16), server_default=text("'none'")),
    Column("velocity", NUMBER(asdecimal=False), server_default=text("0.0")),
    schema="E2EMGR",
)


t_datadescgbt = Table(
    "datadescgbt",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False),
    Column("segment", VARCHAR(4), nullable=False),
    Column("arch_file_id", NUMBER(asdecimal=False), nullable=False),
    Column("data_desc_id", NUMBER(asdecimal=False), nullable=False),
    Column("sub_desc_id", NUMBER(asdecimal=False), nullable=False),
    Column("if_band", VARCHAR(4), nullable=False),
    Column("if_ref_freq", NUMBER(asdecimal=False), nullable=False),
    Column("pol1", NUMBER(asdecimal=False), nullable=False),
    Column("pol2", NUMBER(asdecimal=False), nullable=False),
    Column("pol3", NUMBER(asdecimal=False), nullable=False),
    Column("pol4", NUMBER(asdecimal=False), nullable=False),
    Column("if_conv_chain", NUMBER(asdecimal=False), nullable=False),
    Column("sub_chan_id", NUMBER(asdecimal=False), nullable=False),
    Column("sub_ref_freq", NUMBER(asdecimal=False), nullable=False),
    Column("sub_bandw", NUMBER(asdecimal=False), nullable=False),
    Column("sub_pol1", NUMBER(asdecimal=False), nullable=False),
    Column("sub_pol2", NUMBER(asdecimal=False), nullable=False),
    Column("sub_pol3", NUMBER(asdecimal=False), nullable=False),
    Column("sub_pol4", NUMBER(asdecimal=False), nullable=False),
    Column("sub_net_sideband", NUMBER(asdecimal=False), nullable=False),
    Column("sub_num_chans", NUMBER(asdecimal=False), nullable=False),
    Column("corr_mode", VARCHAR(24), nullable=False),
    Column("if_chan", VARCHAR(8), nullable=False),
    Column("receiver_id", VARCHAR(24), server_default=text("'none'")),
    Column("backend_id", VARCHAR(24), server_default=text("'none'")),
    Column("velocity", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("veldef", VARCHAR(24), server_default=text("'none'")),
    Column(
        "version",
        VARCHAR(16),
        server_default=text(
            """\
'none'
"""
        ),
    ),
    schema="E2EMGR",
)


t_dataproblems = Table(
    "dataproblems",
    metadata,
    Column("error_code", VARCHAR(16), nullable=False),
    Column("starttime", NUMBER(asdecimal=False), nullable=False),
    Column("stoptime", NUMBER(asdecimal=False), nullable=False),
    Column("telescope", VARCHAR(12), nullable=False),
    Column("if_bands", VARCHAR(24), nullable=False),
    Column("error_status", VARCHAR(12), nullable=False),
    Column("description", VARCHAR(64), nullable=False),
    Column("doc_link", VARCHAR(64), nullable=False),
    Column("severity", NUMBER(asdecimal=False), nullable=False, server_default=text("0 ")),
    Index("dataproblems1_idx", "starttime", "stoptime"),
    schema="E2EMGR",
)


t_dataproblink = Table(
    "dataproblink",
    metadata,
    Column("error_code", VARCHAR(16), nullable=False, index=True),
    Column("arch_file_id", NUMBER(asdecimal=False), nullable=False),
    schema="E2EMGR",
)


t_downloadlog = Table(
    "downloadlog",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False, index=True),
    Column("download_date", DateTime, nullable=False, index=True),
    Column("email_addr", VARCHAR(48), nullable=False, index=True),
    Column("ip_addr", VARCHAR(24), nullable=False),
    Column("status", VARCHAR(16), nullable=False),
    Column("sources", VARCHAR(64), nullable=False),
    Column("starttime", NUMBER(asdecimal=False), nullable=False),
    Column("stoptime", NUMBER(asdecimal=False), nullable=False),
    Column("arch_file", VARCHAR(128), nullable=False, index=True),
    Column("out_file", VARCHAR(128), nullable=False),
    Column("result", VARCHAR(32), nullable=False),
    Column("file_size", NUMBER(asdecimal=False)),
    Column("code", VARCHAR(12)),
    schema="E2EMGR",
)


t_emailaddr = Table(
    "emailaddr",
    metadata,
    Column("userlastname", VARCHAR(48), nullable=False),
    Column("userinitials", VARCHAR(24)),
    Column("emailaddr", VARCHAR(64)),
    Index("emailaddr1_idx", "userlastname", "userinitials"),
    schema="E2EMGR",
)


t_file_set_properties = Table(
    "file_set_properties",
    metadata,
    Column("file_set_id", VARCHAR(128), server_default=text("'none'")),
    Column("file_set_alias", VARCHAR(128), server_default=text("'none'")),
    Column("file_set_category", VARCHAR(32), server_default=text("'none'")),
    Column("category_key", VARCHAR(48), server_default=text("'none'")),
    Column("starttime", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("stoptime", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("telescope", VARCHAR(32), server_default=text("'none'")),
    Column("telescope_config", VARCHAR(48), server_default=text("'none'")),
    Column("obs_bands", VARCHAR(48), server_default=text("'none'")),
    Column("processing_history", VARCHAR(128), server_default=text("'none'")),
    Column("collection", VARCHAR(48), server_default=text("'none'")),
    Column("calib_level", NUMBER(asdecimal=False), server_default=text("0")),
    Column(
        "n_file_subsets",
        NUMBER(asdecimal=False),
        server_default=text(
            """\
0
  """
        ),
    ),
    Index("set_properties_indx", "file_set_id", "category_key"),
    schema="E2EMGR",
)


class FirstImage(Base):
    __tablename__ = "first_image"
    __table_args__ = {"schema": "E2EMGR"}

    id = Column(VARCHAR(32), primary_key=True)
    obs_id = Column(VARCHAR(32), server_default=text("null"))
    archive_id = Column(VARCHAR(128), nullable=False)
    htm_id = Column(NUMBER(14, 0, False), server_default=text("0"))
    preview_id = Column(VARCHAR(128), nullable=False)
    access_format = Column(VARCHAR(32), nullable=False)
    access_estsize = Column(NUMBER(14, 0, False), server_default=text("0"))
    dataproduct_type = Column(VARCHAR(16), server_default=text("null"))
    dataproduct_subtype = Column(VARCHAR(32), server_default=text("null"))
    calib_level = Column(NUMBER(6, 0, False), server_default=text("0"))
    dataset_length = Column(NUMBER(14, 0, False), server_default=text("0"))
    im_nsubarrays = Column(NUMBER(8, 0, False), server_default=text("1"))
    im_naxes = Column(NUMBER(8, 0, False), server_default=text("0"))
    im_naxis1 = Column(NUMBER(8, 0, False), server_default=text("0"))
    im_naxis2 = Column(NUMBER(8, 0, False), server_default=text("0"))
    im_naxis3 = Column(NUMBER(8, 0, False), server_default=text("0"))
    im_naxis4 = Column(NUMBER(8, 0, False), server_default=text("0"))
    im_pixtype = Column(VARCHAR(16), server_default=text("null"))
    im_wcsaxes1 = Column(VARCHAR(16), server_default=text("null"))
    im_wcsaxes2 = Column(VARCHAR(16), server_default=text("null"))
    im_wcsaxes3 = Column(VARCHAR(16), server_default=text("null"))
    im_wcsaxes4 = Column(VARCHAR(16), server_default=text("null"))
    im_ra1 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_dec1 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_ra2 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_dec2 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_ra3 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_dec3 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_ra4 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_dec4 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_scale = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    obs_title = Column(VARCHAR(128), server_default=text("null"))
    obs_creator_name = Column(VARCHAR(32), server_default=text("null"))
    obs_collection = Column(VARCHAR(32), server_default=text("null"))
    obs_creator_did = Column(VARCHAR(160), server_default=text("null"))
    obs_publisher_did = Column(VARCHAR(160), server_default=text("null"))
    obs_dataset_did = Column(VARCHAR(160), server_default=text("null"))
    obs_release_date = Column(VARCHAR(20), server_default=text("null"))
    obs_creation_date = Column(VARCHAR(20), server_default=text("null"))
    obs_creation_type = Column(VARCHAR(16), server_default=text("null"))
    facility_name = Column(VARCHAR(20), server_default=text("null"))
    instrument_name = Column(VARCHAR(20), server_default=text("null"))
    obs_bandpass = Column(VARCHAR(20), server_default=text("null"))
    obs_datasource = Column(VARCHAR(20), server_default=text("null"))
    proposal_id = Column(VARCHAR(20), server_default=text("null"))
    target_name = Column(VARCHAR(20), server_default=text("null"))
    target_class = Column(VARCHAR(20), server_default=text("null"))
    s_ra = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    s_dec = Column(NUMBER(asdecimal=False), index=True, server_default=text("0.0"))
    s_fov = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    s_region = Column(VARCHAR(128), server_default=text("null"))
    s_calib_status = Column(VARCHAR(32), server_default=text("'none'"))
    s_resolution = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    em_min = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    em_max = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    em_resolution = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    em_respower = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    t_min = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    t_max = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    t_exptime = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    t_resolution = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    o_ucd = Column(VARCHAR(20), server_default=text("null"))
    o_unit = Column(VARCHAR(32), server_default=text("'none'"))
    pol_states = Column(VARCHAR(20), server_default=text("null"))
    project_code = Column(VARCHAR(24), server_default=text("null"))
    obs_session = Column(VARCHAR(24), server_default=text("null"))
    file_id = Column(VARCHAR(64), server_default=text("null"))
    file_set_id = Column(VARCHAR(128), server_default=text("null"))
    file_subset_id = Column(VARCHAR(128), server_default=text("null"))
    dataset = Column(VARCHAR(128), server_default=text("null"))
    image_file = Column(VARCHAR(128), server_default=text("null"))
    obs_file_id = Column(VARCHAR(64), server_default=text("null"))
    cal_file_id = Column(VARCHAR(64), server_default=text("null"))
    root_dir = Column(VARCHAR(128), server_default=text("null"))
    file_dir = Column(
        VARCHAR(128),
        server_default=text(
            """\
null
"""
        ),
    )


t_firstcatalog = Table(
    "firstcatalog",
    metadata,
    Column("rarad", NUMBER(asdecimal=False), nullable=False),
    Column("decrad", NUMBER(asdecimal=False), nullable=False),
    Column("warn", VARCHAR(2), nullable=False),
    Column("pflux", NUMBER(asdecimal=False), nullable=False),
    Column("flux", NUMBER(asdecimal=False), nullable=False),
    Column("rms", NUMBER(asdecimal=False), nullable=False),
    Column("majorax", NUMBER(asdecimal=False), nullable=False),
    Column("minorax", NUMBER(asdecimal=False), nullable=False),
    Column("posangle", NUMBER(asdecimal=False), nullable=False),
    Column("fmajorax", NUMBER(asdecimal=False), nullable=False),
    Column("fminorax", NUMBER(asdecimal=False), nullable=False),
    Column("fposangle", NUMBER(asdecimal=False), nullable=False),
    Column("field", VARCHAR(14), nullable=False),
    Column("name", VARCHAR(16)),
    schema="E2EMGR",
)


t_image = Table(
    "image",
    metadata,
    Column("identity", VARCHAR(16), nullable=False, index=True),
    Column("telescope", VARCHAR(12), nullable=False),
    Column("teleconfig", VARCHAR(8), nullable=False),
    Column("instrument", VARCHAR(24), nullable=False),
    Column("observer", VARCHAR(48), nullable=False),
    Column("projectcode", VARCHAR(16), nullable=False),
    Column("fieldname", VARCHAR(24), nullable=False),
    Column("naxes", NUMBER(asdecimal=False), nullable=False),
    Column("imagemax", NUMBER(asdecimal=False), nullable=False),
    Column("imagemin", NUMBER(asdecimal=False), nullable=False),
    Column("imagesens", NUMBER(asdecimal=False), nullable=False),
    Column("imagescale", NUMBER(asdecimal=False), nullable=False),
    Column("imagezero", NUMBER(asdecimal=False), nullable=False),
    Column("imageunits", VARCHAR(16), nullable=False),
    Column("restoremaj", NUMBER(asdecimal=False), nullable=False),
    Column("restoremin", NUMBER(asdecimal=False), nullable=False),
    Column("restorepa", NUMBER(asdecimal=False), nullable=False),
    Column("firsttime", NUMBER(asdecimal=False), nullable=False),
    Column("midobstime", NUMBER(asdecimal=False), nullable=False),
    Column("exposure", NUMBER(asdecimal=False), nullable=False),
    Column("imagedate", NUMBER(asdecimal=False), nullable=False),
    Column("coordframe", VARCHAR(16), nullable=False),
    Column("projection", VARCHAR(16), nullable=False),
    Column("equinox", NUMBER(asdecimal=False), nullable=False),
    Column("region", VARCHAR(16), nullable=False),
    Column("racenter", NUMBER(asdecimal=False), nullable=False),
    Column("deccenter", NUMBER(asdecimal=False), nullable=False),
    Column("ramin", NUMBER(asdecimal=False), nullable=False),
    Column("ramax", NUMBER(asdecimal=False), nullable=False),
    Column("decmin", NUMBER(asdecimal=False), nullable=False),
    Column("decmax", NUMBER(asdecimal=False), nullable=False),
    Column("rarefpix", NUMBER(asdecimal=False), nullable=False),
    Column("raref", NUMBER(asdecimal=False), nullable=False),
    Column("radelt", NUMBER(asdecimal=False), nullable=False),
    Column("rapixels", NUMBER(asdecimal=False), nullable=False),
    Column("decrefpix", NUMBER(asdecimal=False), nullable=False),
    Column("decref", NUMBER(asdecimal=False), nullable=False),
    Column("decdelt", NUMBER(asdecimal=False), nullable=False),
    Column("decpixels", NUMBER(asdecimal=False), nullable=False),
    Column("rotangle", NUMBER(asdecimal=False), nullable=False),
    Column("obsband", VARCHAR(8), nullable=False),
    Column("frequency", NUMBER(asdecimal=False), nullable=False),
    Column("bandwd", NUMBER(asdecimal=False), nullable=False),
    Column("nspect", NUMBER(asdecimal=False), nullable=False),
    Column("reffreqpix", NUMBER(asdecimal=False), nullable=False),
    Column("reffreq", NUMBER(asdecimal=False), nullable=False),
    Column("freqincre", NUMBER(asdecimal=False), nullable=False),
    Column("npolar", NUMBER(asdecimal=False), nullable=False),
    Column("polpixels", VARCHAR(12), nullable=False),
    Column("imagequal", VARCHAR(6), nullable=False),
    Column("photoerr", NUMBER(asdecimal=False), nullable=False),
    Column("raerr", NUMBER(asdecimal=False), nullable=False),
    Column("decerr", NUMBER(asdecimal=False), nullable=False),
    Column("specterr", NUMBER(asdecimal=False), nullable=False),
    Column("imagefile", VARCHAR(128), nullable=False),
    Column("imageformat", VARCHAR(24), nullable=False),
    Column("rootdirectory", VARCHAR(128), nullable=False),
    Column("refurl", VARCHAR(128), nullable=False),
    Column("collection", VARCHAR(24)),
    Column("filesize", NUMBER(asdecimal=False)),
    Column("arch_file_id", NUMBER(asdecimal=False)),
    Column("common_file_id", VARCHAR(80)),
    Index("image1_idx", "racenter", "deccenter"),
    schema="E2EMGR",
)


t_ingest_stats = Table(
    "ingest_stats",
    metadata,
    Column("ingestion_date", VARCHAR(24), server_default=text("'none'")),
    Column("ingestion_total", NUMBER(20, 0, False), server_default=text("0")),
    Column("telescope", VARCHAR(12), server_default=text("'none'")),
    Column("data_type", VARCHAR(24), server_default=text("'none'")),
    Column("root_dir", VARCHAR(128), server_default=text("'none'")),
    Column(
        "ngas_host",
        VARCHAR(64),
        server_default=text(
            """\
'none'
"""
        ),
    ),
    schema="E2EMGR",
)


t_logfiles = Table(
    "logfiles",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False, index=True),
    Column("raw_project_code", VARCHAR(16), nullable=False),
    Column("dynamic_tag", VARCHAR(16), nullable=False),
    Column("telescope", VARCHAR(12), nullable=False),
    Column("observer", VARCHAR(48), nullable=False),
    Column("starttime", NUMBER(asdecimal=False), nullable=False),
    Column("stoptime", NUMBER(asdecimal=False), nullable=False),
    Column("sched_type", VARCHAR(16), nullable=False),
    Column("site_code", VARCHAR(8), nullable=False),
    Column("root_directory", VARCHAR(64), nullable=False),
    Column("file_name", VARCHAR(64), nullable=False),
    Column("mimetype", VARCHAR(80), nullable=False),
    Column("obsfiles", VARCHAR(128), nullable=False),
    schema="E2EMGR",
)


class NgasCache(Base):
    __tablename__ = "ngas_cache"
    __table_args__ = {"schema": "E2EMGR"}

    disk_id = Column(VARCHAR(128), primary_key=True, nullable=False)
    file_id = Column(VARCHAR(64), primary_key=True, nullable=False)
    file_version = Column(Integer, primary_key=True, nullable=False)
    cache_time = Column(NUMBER(16, 6, True), nullable=False)
    cache_delete = Column(Integer, nullable=False)


t_ngas_file_sets = Table(
    "ngas_file_sets",
    metadata,
    Column("file_id", VARCHAR(64), nullable=False),
    Column("file_version", NUMBER(12, 0, False), server_default=text("1")),
    Column("file_set_id", VARCHAR(64), nullable=False),
    Column("entity_type_name", VARCHAR(48), nullable=False),
    Column("entity_id", VARCHAR(48), nullable=False),
    Column("format", VARCHAR(48), server_default=text("'none'")),
    Column("file_id_alias", VARCHAR(128), server_default=text("'none'")),
    Column("native_ext", VARCHAR(24), server_default=text("'none'")),
    Column("file_subset_id", VARCHAR(48), server_default=text("'none'")),
    Index("ngas_file_sets_indx", "file_id", "file_version", "file_set_id"),
    schema="E2EMGR",
)


class NgasMirroringBookkeeping(Base):
    __tablename__ = "ngas_mirroring_bookkeeping"
    __table_args__ = (
        Index("nmb_thost_status_shost_idx", "target_cluster", "target_host", "status", "source_host"),
        Index("nmb_iter_status_idx", "iteration", "status"),
        {"schema": "E2EMGR"},
    )

    file_id = Column(VARCHAR(64), primary_key=True, nullable=False)
    file_version = Column(NUMBER(22, 0, False), primary_key=True, nullable=False)
    file_size = Column(NUMBER(20, 0, False))
    disk_id = Column(VARCHAR(128))
    host_id = Column(VARCHAR(32))
    format = Column(VARCHAR(32))
    status = Column(CHAR(8), nullable=False)
    target_cluster = Column(VARCHAR(64))
    target_host = Column(VARCHAR(64))
    archive_command = Column(VARCHAR(118))
    source_host = Column(VARCHAR(64), nullable=False)
    retrieve_command = Column(VARCHAR(118))
    ingestion_date = Column(VARCHAR(23))
    ingestion_time = Column(Float)
    iteration = Column(NUMBER(22, 0, False), primary_key=True, nullable=False)
    checksum = Column(VARCHAR(64), nullable=False)
    staging_file = Column(VARCHAR(256))
    attempt = Column(NUMBER(4, 0, False))
    downloaded_bytes = Column(NUMBER(22, 0, False))


class NgasMirroringHist(Base):
    __tablename__ = "ngas_mirroring_hist"
    __table_args__ = {"schema": "E2EMGR"}

    instance_id = Column(VARCHAR(32), nullable=False)
    file_id = Column(VARCHAR(64), primary_key=True, nullable=False)
    file_version = Column(Integer, primary_key=True, nullable=False)
    ingestion_date = Column(VARCHAR(23), nullable=False)
    srv_list_id = Column(Integer, nullable=False)
    xml_file_info = Column(VARCHAR(2000), nullable=False)
    status = Column(Integer, nullable=False)
    message = Column(VARCHAR(2000))
    last_activity_time = Column(VARCHAR(23), nullable=False)
    scheduling_time = Column(VARCHAR(23), nullable=False)


class NgasMirroringQueue(Base):
    __tablename__ = "ngas_mirroring_queue"
    __table_args__ = {"schema": "E2EMGR"}

    instance_id = Column(VARCHAR(32), nullable=False)
    file_id = Column(VARCHAR(64), primary_key=True, nullable=False)
    file_version = Column(Integer, primary_key=True, nullable=False)
    ingestion_date = Column(VARCHAR(23), nullable=False)
    srv_list_id = Column(Integer, nullable=False)
    xml_file_info = Column(VARCHAR(2000), nullable=False)
    status = Column(Integer, nullable=False)
    message = Column(VARCHAR(2000))
    last_activity_time = Column(VARCHAR(23), nullable=False)
    scheduling_time = Column(VARCHAR(23), nullable=False)


class NgasSrvList(Base):
    __tablename__ = "ngas_srv_list"
    __table_args__ = {"schema": "E2EMGR"}

    srv_list_id = Column(Integer, primary_key=True)
    srv_list = Column(VARCHAR(255), nullable=False)
    creation_date = Column(VARCHAR(23), nullable=False)


class Nvsscatalog(Base):
    __tablename__ = "nvsscatalog"
    __table_args__ = {"schema": "E2EMGR"}

    rarad = Column(NUMBER(asdecimal=False), primary_key=True, nullable=False)
    decrad = Column(NUMBER(asdecimal=False), primary_key=True, nullable=False)
    raerror = Column(NUMBER(asdecimal=False), nullable=False)
    decerror = Column(NUMBER(asdecimal=False), nullable=False)
    flux = Column(NUMBER(asdecimal=False), nullable=False)
    fluxerror = Column(NUMBER(asdecimal=False), nullable=False)
    majorsym = Column(VARCHAR(4), nullable=False)
    majorax = Column(NUMBER(asdecimal=False), nullable=False)
    majorerr = Column(NUMBER(asdecimal=False), nullable=False)
    minorsym = Column(VARCHAR(4), nullable=False)
    minorax = Column(NUMBER(asdecimal=False), nullable=False)
    minorerr = Column(NUMBER(asdecimal=False), nullable=False)
    posangle = Column(NUMBER(asdecimal=False), nullable=False)
    paerror = Column(NUMBER(asdecimal=False), nullable=False)
    rescode = Column(VARCHAR(4), nullable=False)
    reserror = Column(NUMBER(asdecimal=False), nullable=False)
    pflux = Column(NUMBER(asdecimal=False), nullable=False)
    pfluxerror = Column(NUMBER(asdecimal=False), nullable=False)
    pangle = Column(NUMBER(asdecimal=False), nullable=False)
    pangleerror = Column(NUMBER(asdecimal=False), nullable=False)
    field = Column(VARCHAR(10), nullable=False)
    centerx = Column(NUMBER(asdecimal=False), nullable=False)
    centery = Column(NUMBER(asdecimal=False), nullable=False)
    name = Column(VARCHAR(10))


t_observation = Table(
    "observation",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False, index=True),
    Column("segment", VARCHAR(4), nullable=False),
    Column("obs_type", VARCHAR(24), nullable=False),
    Column("starttime", NUMBER(asdecimal=False), nullable=False),
    Column("stoptime", NUMBER(asdecimal=False), nullable=False),
    Column("source_id", VARCHAR(24), nullable=False, index=True),
    Column("source_type", VARCHAR(8), nullable=False),
    Column("calib_type", VARCHAR(8), nullable=False),
    Column("corr_mode", VARCHAR(16), nullable=False),
    Column("ra2000", NUMBER(asdecimal=False), nullable=False),
    Column("dec2000", NUMBER(asdecimal=False), nullable=False),
    Column("frame", VARCHAR(20), nullable=False),
    Column("subarray_id", NUMBER(asdecimal=False), nullable=False),
    Column("data_desc_id", NUMBER(asdecimal=False), nullable=False, index=True),
    Column("arch_file_id", NUMBER(asdecimal=False), nullable=False, index=True),
    Column("exposure", NUMBER(asdecimal=False), nullable=False),
    Column("interval", NUMBER(asdecimal=False), nullable=False),
    Column("uv_min", NUMBER(asdecimal=False), nullable=False),
    Column("uv_max", NUMBER(asdecimal=False), nullable=False),
    Column("sub_desc_id", NullType),
    Column("elev_min", NUMBER(asdecimal=False), nullable=False),
    Column("elev_max", NUMBER(asdecimal=False), nullable=False),
    Column("n_ants", NUMBER(asdecimal=False)),
    Column("ra_epoch", NUMBER(asdecimal=False)),
    Column("dec_epoch", NUMBER(asdecimal=False)),
    Column("bdf_file", VARCHAR(64)),
    Column("config_desc_id", VARCHAR(48), server_default=text("'none'")),
    Column("scan", NUMBER(19, 0, False), server_default=text("0")),
    Column("subscan", NUMBER(19, 0, False), server_default=text("0")),
    Column("scan_intent", VARCHAR(256), server_default=text("'none'")),
    Column("procname", VARCHAR(24), server_default=text("'none'")),
    Column("proctype", VARCHAR(24), server_default=text("'none'")),
    Column("gbtobstype", VARCHAR(24), server_default=text("'none'")),
    Column("msgflag", VARCHAR(128), server_default=text("'none'")),
    Column("msglevel", NUMBER(8, 0, False), server_default=text("0")),
    Index("observation4_idx", "starttime", "stoptime"),
    Index("observation5_idx", "ra2000", "dec2000"),
    schema="E2EMGR",
)


t_observationgbt = Table(
    "observationgbt",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False),
    Column("segment", VARCHAR(4), nullable=False),
    Column("obs_type", VARCHAR(24), nullable=False),
    Column("starttime", NUMBER(asdecimal=False), nullable=False),
    Column("stoptime", NUMBER(asdecimal=False), nullable=False),
    Column("source_id", VARCHAR(16), nullable=False),
    Column("source_type", VARCHAR(8), nullable=False),
    Column("calib_type", VARCHAR(8), nullable=False),
    Column("corr_mode", VARCHAR(16), nullable=False),
    Column("ra2000", NUMBER(asdecimal=False), nullable=False),
    Column("dec2000", NUMBER(asdecimal=False), nullable=False),
    Column("frame", VARCHAR(20), nullable=False),
    Column("subarray_id", NUMBER(asdecimal=False), nullable=False),
    Column("data_desc_id", NUMBER(asdecimal=False), nullable=False),
    Column("arch_file_id", NUMBER(asdecimal=False), nullable=False),
    Column("exposure", NUMBER(asdecimal=False), nullable=False),
    Column("interval", NUMBER(asdecimal=False), nullable=False),
    Column("uv_min", NUMBER(asdecimal=False), nullable=False),
    Column("uv_max", NUMBER(asdecimal=False), nullable=False),
    Column("sub_desc_id", NullType),
    Column("elev_min", NUMBER(asdecimal=False), nullable=False),
    Column("elev_max", NUMBER(asdecimal=False), nullable=False),
    Column("n_ants", NUMBER(asdecimal=False), nullable=False),
    Column("ra_epoch", NUMBER(asdecimal=False), nullable=False),
    Column("dec_epoch", NUMBER(asdecimal=False), nullable=False),
    Column("bdf_file", VARCHAR(64), server_default=text("'none'")),
    Column("config_desc_id", VARCHAR(48), server_default=text("'none'")),
    Column("scan", NUMBER(19, 0, False), server_default=text("0")),
    Column("subscan", NUMBER(19, 0, False), server_default=text("0")),
    Column("scan_intent", VARCHAR(256), server_default=text("'none'")),
    Column("procname", VARCHAR(24), server_default=text("'none'")),
    Column("proctype", VARCHAR(24), server_default=text("'none'")),
    Column("gbtobstype", VARCHAR(24), server_default=text("'none'")),
    Column(
        "msgflag",
        VARCHAR(128),
        server_default=text(
            """\
'none'
"""
        ),
    ),
    Column("msglevel", NUMBER(8, 0, False), server_default=text("0")),
    schema="E2EMGR",
)


t_obsscripts = Table(
    "obsscripts",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False, index=True),
    Column("raw_project_code", VARCHAR(16), nullable=False),
    Column("dynamic_tag", VARCHAR(16), nullable=False),
    Column("telescope", VARCHAR(12), nullable=False),
    Column("observer", VARCHAR(48), nullable=False),
    Column("starttime", NUMBER(asdecimal=False), nullable=False),
    Column("stoptime", NUMBER(asdecimal=False), nullable=False),
    Column("sched_type", VARCHAR(16), nullable=False),
    Column("site_code", VARCHAR(8), nullable=False),
    Column("root_directory", VARCHAR(64), nullable=False),
    Column("file_name", VARCHAR(64), nullable=False),
    Column("mimetype", VARCHAR(80), nullable=False),
    schema="E2EMGR",
)


t_obsset = Table(
    "obsset",
    metadata,
    Column("dataproduct_type", VARCHAR(24), nullable=False),
    Column("dataproduct_subtype", VARCHAR(24), nullable=False),
    Column("calib_level", NUMBER(asdecimal=False), server_default=text("0")),
    Column("target_name", VARCHAR(48), nullable=False),
    Column("target_class", VARCHAR(24), nullable=False),
    Column("obs_id", VARCHAR(64), nullable=False),
    Column("obs_title", VARCHAR(24), nullable=False),
    Column("obs_collection", VARCHAR(48), nullable=False),
    Column("obs_creation_date", VARCHAR(24), nullable=False),
    Column("obs_creator_name", VARCHAR(48), nullable=False),
    Column("obs_creator_did", VARCHAR(48), nullable=False),
    Column("obs_release_date", VARCHAR(24), nullable=False),
    Column("obs_publisher_did", VARCHAR(64), nullable=False),
    Column("publisher_id", VARCHAR(24), nullable=False),
    Column("bib_reference", VARCHAR(24), nullable=False),
    Column("data_rights", VARCHAR(24), nullable=False),
    Column("access_url", VARCHAR(128), nullable=False),
    Column("access_format", VARCHAR(24), nullable=False),
    Column("access_estsize", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("s_ra", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("s_dec", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("s_fov", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("s_region", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("s_resolution", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("s_ucd", VARCHAR(48), nullable=False),
    Column("s_unit", VARCHAR(24), nullable=False),
    Column("s_resolution_min", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("s_resolution_max", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("s_calib_status", VARCHAR(48), nullable=False),
    Column("s_stat_error", NUMBER(asdecimal=False), server_default=text("0")),
    Column("t_min", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("t_max", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("t_exptime", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("t_resolution", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("t_calib_status", VARCHAR(48), nullable=False),
    Column("t_stat_error", NUMBER(asdecimal=False), server_default=text("0")),
    Column("em_ucd", VARCHAR(48), nullable=False),
    Column("em_unit", VARCHAR(24), nullable=False),
    Column("em_calib_status", VARCHAR(48), nullable=False),
    Column("em_min", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("em_max", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("em_res_power", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("em_res_power_min", NUMBER(asdecimal=False), server_default=text("0")),
    Column("em_res_power_max", NUMBER(asdecimal=False), server_default=text("0")),
    Column("em_resolution", NUMBER(asdecimal=False), server_default=text("0")),
    Column("em_stat_error", NUMBER(asdecimal=False), server_default=text("0")),
    Column("o_ucd", VARCHAR(128), nullable=False),
    Column("o_unit", VARCHAR(24), nullable=False),
    Column("o_calib_status", VARCHAR(24), nullable=False),
    Column("o_stat_error", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("pol_states", VARCHAR(24), nullable=False),
    Column("facility_name", VARCHAR(48), nullable=False),
    Column("instrument_name", VARCHAR(48), nullable=False),
    Column("proposal_id", VARCHAR(48), nullable=False),
    Column("project_code", VARCHAR(24), nullable=False),
    Column("obs_session", VARCHAR(24), nullable=False),
    Column("file_id", VARCHAR(64), nullable=False),
    Column("file_set_id", VARCHAR(128), nullable=False),
    Column("file_subset_id", VARCHAR(128), nullable=False),
    Column("dataset", VARCHAR(128), nullable=False),
    Column("image_file", VARCHAR(128), nullable=False),
    Column(
        "arch_file_id",
        NUMBER(asdecimal=False),
        server_default=text(
            """\
0
"""
        ),
    ),
    Index("obsset_indx", "file_set_id", "file_id", "arch_file_id"),
    schema="E2EMGR",
)


t_obssummary = Table(
    "obssummary",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False, index=True),
    Column("source_id", VARCHAR(24), nullable=False, index=True),
    Column("if_band", VARCHAR(4), nullable=False),
    Column("sub_ref_freq", NUMBER(asdecimal=False), nullable=False),
    Column("starttime", NUMBER(asdecimal=False), nullable=False),
    Column("stoptime", NUMBER(asdecimal=False), nullable=False),
    Column("exposure", NUMBER(asdecimal=False), nullable=False),
    Column("sub_bandw", NUMBER(asdecimal=False), nullable=False),
    Column("telescope", VARCHAR(12), nullable=False),
    Column("telescope_config", VARCHAR(8), nullable=False),
    Column("sub_num_chans", NUMBER(asdecimal=False), nullable=False),
    Column("ra2000", NUMBER(asdecimal=False), nullable=False),
    Column("dec2000", NUMBER(asdecimal=False), nullable=False),
    Column("project_lock", VARCHAR(8), nullable=False),
    Column("sub_pol1", NUMBER(asdecimal=False), nullable=False),
    Column("sub_pol2", NUMBER(asdecimal=False), nullable=False),
    Column("sub_pol3", NUMBER(asdecimal=False), nullable=False),
    Column("sub_pol4", NUMBER(asdecimal=False), nullable=False),
    Column("subarray_id", NUMBER(asdecimal=False), nullable=False),
    Column("corr_mode", VARCHAR(8), nullable=False),
    Column("if_chan", VARCHAR(8), nullable=False),
    Column("n_ants", NUMBER(asdecimal=False), nullable=False),
    Column("arch_file_id", NUMBER(asdecimal=False), nullable=False),
    Column("sub_chan_id", NUMBER(asdecimal=False), nullable=False),
    Column("n_images", NUMBER(asdecimal=False), nullable=False),
    Column("obssummary_uid", VARCHAR(48), nullable=False, index=True),
    Column("file_set_id", VARCHAR(64), nullable=False),
    Column("radeg", NUMBER(asdecimal=False)),
    Column("decdeg", NUMBER(asdecimal=False)),
    Column("distance", NUMBER(asdecimal=False)),
    Column("rms", NUMBER(asdecimal=False)),
    Column("resol", NUMBER(asdecimal=False)),
    Column("fov", NUMBER(asdecimal=False)),
    Column("polar", VARCHAR(16)),
    Index("obssummary2_idx", "ra2000", "dec2000"),
    Index("obssummary4_idx", "starttime", "stoptime"),
    Index("obssummary6_idx", "radeg", "decdeg"),
    schema="E2EMGR",
)


t_obssummary_columns = Table(
    "obssummary_columns",
    metadata,
    Column("column_name", VARCHAR(32), nullable=False, index=True),
    Column("table_name", VARCHAR(32), nullable=False),
    Column("description", VARCHAR(64), nullable=False),
    Column("unit", VARCHAR(16), nullable=False),
    Column("ucd", VARCHAR(64), nullable=False),
    Column("utype", VARCHAR(64), nullable=False),
    Column("datatype", VARCHAR(32), nullable=False),
    Column("varsize", NUMBER(asdecimal=False), nullable=False),
    Column("primary", VARCHAR(16), nullable=False),
    Column("indexed", VARCHAR(16), nullable=False),
    Column("std", VARCHAR(16), nullable=False),
    schema="E2EMGR",
)


t_omsstnsched = Table(
    "omsstnsched",
    metadata,
    Column("proposal", VARCHAR(5), nullable=False, index=True),
    Column("segment", VARCHAR(2), nullable=False),
    Column("staid", VARCHAR(5), nullable=False),
    Column("start_time", DateTime, nullable=False),
    Column("stop_time", DateTime, nullable=False),
    Column("mjdstart", NUMBER(16, 8, True)),
    Column("mjdstop", NUMBER(16, 8, True)),
    Index("omsstnsched2_idx", "mjdstart", "mjdstop"),
    schema="E2EMGR",
)


t_pidum = Table(
    "pidum",
    metadata,
    Column("proposal", VARCHAR(16), nullable=False),
    Column("pi_lastname", VARCHAR(48), nullable=False),
    Column("pi_firstname", VARCHAR(48), nullable=False),
    Column("pi_name", VARCHAR(64), nullable=False),
    Column("peoplekey", NUMBER(asdecimal=False), nullable=False),
    schema="E2EMGR",
)


t_pipequeue = Table(
    "pipequeue",
    metadata,
    Column("project_code", VARCHAR(16), server_default=text("'none'")),
    Column("arch_file_id", NUMBER(asdecimal=False), server_default=text("0")),
    Column("arch_file", VARCHAR(128), server_default=text("'none'")),
    Column("file_set_type", VARCHAR(16), server_default=text("'RAW'")),
    Column("sb_type", VARCHAR(32), server_default=text("'none'")),
    Column("queuedate", VARCHAR(23), server_default=text("'none'")),
    Column(
        "status",
        VARCHAR(16),
        server_default=text(
            """\
'none'
"""
        ),
    ),
    Column("submitdate", VARCHAR(23), server_default=text("'none'")),
    schema="E2EMGR",
)


t_pipequeuetemp = Table(
    "pipequeuetemp",
    metadata,
    Column("project_code", VARCHAR(16), server_default=text("'none'")),
    Column("arch_file_id", NUMBER(asdecimal=False), server_default=text("0")),
    Column("arch_file", VARCHAR(128), server_default=text("'none'")),
    Column("file_set_type", VARCHAR(16), server_default=text("'RAW'")),
    Column("sb_type", VARCHAR(32), server_default=text("'none'")),
    Column("queuedate", DateTime, server_default=text("sysdate")),
    Column(
        "status",
        VARCHAR(16),
        server_default=text(
            """\
'none'
"""
        ),
    ),
    schema="E2EMGR",
)


t_project = Table(
    "project",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False, index=True),
    Column("observer", VARCHAR(48), nullable=False, index=True),
    Column("observer_id", NUMBER(asdecimal=False), nullable=False),
    Column("starttime", NUMBER(asdecimal=False), nullable=False),
    Column("stoptime", NUMBER(asdecimal=False), nullable=False),
    Column("proprietary", NUMBER(asdecimal=False), nullable=False, index=True),
    Column("telescope", VARCHAR(12), nullable=False),
    Column("telescope_config", VARCHAR(36), nullable=False),
    Column("obs_bands", VARCHAR(24), nullable=False),
    Column("total_obs_time", NUMBER(asdecimal=False), nullable=False),
    Column("num_segments", NUMBER(asdecimal=False), nullable=False),
    Column("arch_files", NUMBER(asdecimal=False), nullable=False),
    Column("row_date", NUMBER(asdecimal=False), nullable=False),
    Column("raw_project_code", VARCHAR(16), nullable=False, index=True),
    Column("project_lock", VARCHAR(8), nullable=False, index=True),
    Column("unlock_expire", NUMBER(asdecimal=False), nullable=False),
    Column("grant_access", VARCHAR(12), nullable=False),
    Column("proprietary_duration", NUMBER(asdecimal=False), nullable=False),
    Column("warned", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column("project_id", NUMBER(asdecimal=False), server_default=text("0")),
    Index("project2_idx", "starttime", "stoptime"),
    schema="E2EMGR",
)


t_projectgbt = Table(
    "projectgbt",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False),
    Column("observer", VARCHAR(48), nullable=False),
    Column("observer_id", NUMBER(asdecimal=False), nullable=False),
    Column("starttime", NUMBER(asdecimal=False), nullable=False),
    Column("stoptime", NUMBER(asdecimal=False), nullable=False),
    Column("proprietary", NUMBER(asdecimal=False), nullable=False),
    Column("telescope", VARCHAR(12), nullable=False),
    Column("telescope_config", VARCHAR(24), nullable=False),
    Column("obs_bands", VARCHAR(24), nullable=False),
    Column("total_obs_time", NUMBER(asdecimal=False), nullable=False),
    Column("num_segments", NUMBER(asdecimal=False), nullable=False),
    Column("arch_files", NUMBER(asdecimal=False), nullable=False),
    Column("row_date", NUMBER(asdecimal=False), nullable=False),
    Column("raw_project_code", VARCHAR(16), nullable=False),
    Column("project_lock", VARCHAR(8), nullable=False),
    Column("unlock_expire", NUMBER(asdecimal=False), nullable=False),
    Column("grant_access", VARCHAR(12), nullable=False),
    Column("proprietary_duration", NUMBER(asdecimal=False), nullable=False),
    Column("warned", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column(
        "project_id",
        NUMBER(asdecimal=False),
        server_default=text(
            """\
0
   """
        ),
    ),
    schema="E2EMGR",
)


t_projectgbtold = Table(
    "projectgbtold",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False),
    Column("observer", VARCHAR(48), nullable=False),
    Column("observer_id", NUMBER(asdecimal=False), nullable=False),
    Column("starttime", NUMBER(asdecimal=False), nullable=False),
    Column("stoptime", NUMBER(asdecimal=False), nullable=False),
    Column("proprietary", NUMBER(asdecimal=False), nullable=False),
    Column("telescope", VARCHAR(12), nullable=False),
    Column("telescope_config", VARCHAR(24), nullable=False),
    Column("obs_bands", VARCHAR(24), nullable=False),
    Column("total_obs_time", NUMBER(asdecimal=False), nullable=False),
    Column("num_segments", NUMBER(asdecimal=False), nullable=False),
    Column("arch_files", NUMBER(asdecimal=False), nullable=False),
    Column("row_date", NUMBER(asdecimal=False), nullable=False),
    Column("raw_project_code", VARCHAR(16), nullable=False),
    Column("project_lock", VARCHAR(8), nullable=False),
    Column("unlock_expire", NUMBER(asdecimal=False), nullable=False),
    Column("grant_access", VARCHAR(12), nullable=False),
    Column("proprietary_duration", NUMBER(asdecimal=False), nullable=False),
    Column("warned", NUMBER(asdecimal=False), server_default=text("0.0")),
    Column(
        "project_id",
        NUMBER(asdecimal=False),
        server_default=text(
            """\
0
   """
        ),
    ),
    schema="E2EMGR",
)


t_proposal = Table(
    "proposal",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False, index=True),
    Column("pi_name", VARCHAR(48), nullable=False, index=True),
    Column("pi_email", VARCHAR(64), nullable=False),
    Column("raw_project_code", VARCHAR(16), nullable=False, index=True),
    schema="E2EMGR",
)


t_proprietary = Table(
    "proprietary",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False),
    Column("observer", VARCHAR(24), nullable=False),
    Column("proprietary", NUMBER(asdecimal=False), nullable=False),
    Column("telescope", VARCHAR(12), nullable=False),
    Column("raw_project_code", VARCHAR(16), nullable=False),
    Column("keyword", VARCHAR(12), nullable=False),
    Column("date_expires", NUMBER(asdecimal=False), nullable=False),
    Column("entry_date", NUMBER(asdecimal=False), nullable=False),
    Column("email_addr", VARCHAR(64), nullable=False),
    Index("proprietary_idx", "project_code", "observer"),
    schema="E2EMGR",
)


t_segment = Table(
    "segment",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False),
    Column("segment", VARCHAR(4), nullable=False),
    Column("observer", VARCHAR(36), nullable=False, index=True),
    Column("observer_id", NUMBER(asdecimal=False), nullable=False),
    Column("starttime", NUMBER(asdecimal=False), nullable=False),
    Column("stoptime", NUMBER(asdecimal=False), nullable=False),
    Column("proprietary", NUMBER(asdecimal=False), nullable=False),
    Column("telescope", VARCHAR(12), nullable=False),
    Column("telescope_config", VARCHAR(24), nullable=False),
    Column("obs_bands", VARCHAR(16), nullable=False),
    Column("total_obs_time", NUMBER(asdecimal=False), nullable=False),
    Column("num_scans", NUMBER(asdecimal=False), nullable=False),
    Column("arch_files", NUMBER(asdecimal=False), nullable=False),
    Column("row_date", NUMBER(asdecimal=False), nullable=False),
    Column("raw_project_code", VARCHAR(16), nullable=False, index=True),
    Column("project_lock", VARCHAR(8), nullable=False),
    Column("unlock_expire", NUMBER(asdecimal=False), nullable=False),
    Column("grant_access", VARCHAR(12), nullable=False),
    Column("proprietary_duration", NUMBER(asdecimal=False), nullable=False),
    Index("segment1_idx", "project_code", "segment"),
    Index("segment2_idx", "starttime", "stoptime"),
    schema="E2EMGR",
)


t_shiporders = Table(
    "shiporders",
    metadata,
    Column("file_set_id", VARCHAR(96), nullable=False),
    Column("order_id", NUMBER(asdecimal=False), nullable=False),
    Column("user_id", NUMBER(asdecimal=False), nullable=False),
    Column("emailaddr", VARCHAR(48), server_default=text("'none'")),
    Column("submission_date", VARCHAR(48), server_default=text("'none'")),
    Column(
        "status",
        VARCHAR(24),
        server_default=text(
            """\
'none'
"""
        ),
    ),
    Column(
        "useros",
        VARCHAR(24),
        server_default=text(
            """\
'none'
"""
        ),
    ),
    schema="E2EMGR",
)


class Siav2image(Base):
    __tablename__ = "siav2image"
    __table_args__ = {"schema": "E2EMGR"}

    id = Column(VARCHAR(32), primary_key=True)
    obs_id = Column(VARCHAR(32), server_default=text("null"))
    archive_id = Column(VARCHAR(128), nullable=False)
    htm_id = Column(NUMBER(14, 0, False), server_default=text("0"))
    preview_id = Column(VARCHAR(128), nullable=False)
    access_format = Column(VARCHAR(32), nullable=False)
    access_estsize = Column(NUMBER(14, 0, False), server_default=text("0"))
    dataproduct_type = Column(VARCHAR(16), server_default=text("null"))
    dataproduct_subtype = Column(VARCHAR(32), server_default=text("null"))
    calib_level = Column(NUMBER(6, 0, False), server_default=text("0"))
    dataset_length = Column(NUMBER(14, 0, False), server_default=text("0"))
    im_nsubarrays = Column(NUMBER(8, 0, False), server_default=text("1"))
    im_naxes = Column(NUMBER(8, 0, False), server_default=text("0"))
    im_naxis1 = Column(NUMBER(8, 0, False), server_default=text("0"))
    im_naxis2 = Column(NUMBER(8, 0, False), server_default=text("0"))
    im_naxis3 = Column(NUMBER(8, 0, False), server_default=text("0"))
    im_naxis4 = Column(NUMBER(8, 0, False), server_default=text("0"))
    im_pixtype = Column(VARCHAR(16), server_default=text("null"))
    im_wcsaxes1 = Column(VARCHAR(16), server_default=text("null"))
    im_wcsaxes2 = Column(VARCHAR(16), server_default=text("null"))
    im_wcsaxes3 = Column(VARCHAR(16), server_default=text("null"))
    im_wcsaxes4 = Column(VARCHAR(16), server_default=text("null"))
    im_ra1 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_dec1 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_ra2 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_dec2 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_ra3 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_dec3 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_ra4 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_dec4 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_scale = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    obs_title = Column(VARCHAR(128), server_default=text("null"))
    obs_creator_name = Column(VARCHAR(32), server_default=text("null"))
    obs_collection = Column(VARCHAR(32), server_default=text("null"))
    obs_creator_did = Column(VARCHAR(160), server_default=text("null"))
    obs_publisher_did = Column(VARCHAR(160), server_default=text("null"))
    obs_dataset_did = Column(VARCHAR(160), server_default=text("null"))
    obs_release_date = Column(VARCHAR(20), server_default=text("null"))
    obs_creation_date = Column(VARCHAR(20), server_default=text("null"))
    obs_creation_type = Column(VARCHAR(16), server_default=text("null"))
    facility_name = Column(VARCHAR(20), server_default=text("null"))
    instrument_name = Column(VARCHAR(20), server_default=text("null"))
    obs_bandpass = Column(VARCHAR(20), server_default=text("null"))
    obs_datasource = Column(VARCHAR(20), server_default=text("null"))
    proposal_id = Column(VARCHAR(20), server_default=text("null"))
    target_name = Column(VARCHAR(20), server_default=text("null"))
    target_class = Column(VARCHAR(20), server_default=text("null"))
    s_ra = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    s_dec = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    s_fov = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    s_region = Column(VARCHAR(128), server_default=text("null"))
    s_calib_status = Column(VARCHAR(32), server_default=text("'none'"))
    s_resolution = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    em_min = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    em_max = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    em_resolution = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    em_respower = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    t_min = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    t_max = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    t_exptime = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    t_resolution = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    o_ucd = Column(VARCHAR(20), server_default=text("null"))
    o_unit = Column(VARCHAR(32), server_default=text("'none'"))
    pol_states = Column(VARCHAR(20), server_default=text("null"))
    project_code = Column(VARCHAR(24), server_default=text("null"))
    obs_session = Column(VARCHAR(24), server_default=text("null"))
    file_id = Column(VARCHAR(64), server_default=text("null"))
    file_set_id = Column(VARCHAR(128), server_default=text("null"))
    file_subset_id = Column(VARCHAR(128), server_default=text("null"))
    dataset = Column(VARCHAR(128), server_default=text("null"))
    image_file = Column(VARCHAR(128), server_default=text("null"))
    obs_file_id = Column(NUMBER(asdecimal=False), server_default=text("0"))
    cal_file_id = Column(NUMBER(asdecimal=False), server_default=text("0"))
    root_dir = Column(VARCHAR(128), server_default=text("null"))
    file_dir = Column(
        VARCHAR(128),
        server_default=text(
            """\
null
"""
        ),
    )


t_subarray = Table(
    "subarray",
    metadata,
    Column("project_code", VARCHAR(16), nullable=False),
    Column("segment", VARCHAR(4)),
    Column("starttime", NUMBER(asdecimal=False), nullable=False),
    Column("stoptime", NUMBER(asdecimal=False), nullable=False),
    Column("subarray_id", NUMBER(asdecimal=False), nullable=False),
    Column("antenna_id", NUMBER(asdecimal=False), nullable=False),
    Index("subarray_idx", "project_code", "starttime", "stoptime", "subarray_id"),
    schema="E2EMGR",
)


t_sumlist = Table(
    "sumlist",
    metadata,
    Column("programid", VARCHAR(8), nullable=False, index=True),
    Column("sourcename", VARCHAR(16), nullable=False, index=True),
    Column("qualifier", VARCHAR(2), nullable=False),
    Column("observerid", NUMBER(asdecimal=False), nullable=False),
    Column("observername", VARCHAR(20), nullable=False),
    Column("centerofbw1", NUMBER(asdecimal=False), nullable=False),
    Column("centerofbw2", NUMBER(asdecimal=False), nullable=False),
    Column("centerofbw3", NUMBER(asdecimal=False), nullable=False),
    Column("centerofbw4", NUMBER(asdecimal=False), nullable=False),
    Column("bandwidth1", NUMBER(asdecimal=False), nullable=False),
    Column("bandwidth2", NUMBER(asdecimal=False), nullable=False),
    Column("bandwidth3", NUMBER(asdecimal=False), nullable=False),
    Column("bandwidth4", NUMBER(asdecimal=False), nullable=False),
    Column("netsideband1", VARCHAR(2), nullable=False),
    Column("netsideband2", VARCHAR(2), nullable=False),
    Column("netsideband3", VARCHAR(2), nullable=False),
    Column("netsideband4", VARCHAR(2), nullable=False),
    Column("obsmode", VARCHAR(3), nullable=False),
    Column("calcode", VARCHAR(3), nullable=False),
    Column("correlator", VARCHAR(4), nullable=False),
    Column("planetary", VARCHAR(2), nullable=False),
    Column("subarrayid", VARCHAR(2), nullable=False),
    Column("epoch", VARCHAR(5), nullable=False),
    Column("ra1950", NUMBER(asdecimal=False), nullable=False),
    Column("dec1950", NUMBER(asdecimal=False), nullable=False),
    Column("ra2000", NUMBER(asdecimal=False), nullable=False),
    Column("dec2000", NUMBER(asdecimal=False), nullable=False),
    Column("mjad", DateTime, nullable=False, index=True),
    Column("antennae", NUMBER(asdecimal=False), nullable=False),
    Column("starttimelst", NUMBER(asdecimal=False), nullable=False),
    Column("starttimeiat", NUMBER(asdecimal=False), nullable=False),
    Column("stoptimelst", NUMBER(asdecimal=False), nullable=False),
    Column("stoptimeiat", NUMBER(asdecimal=False), nullable=False),
    Column("timeonsource", NUMBER(asdecimal=False), nullable=False),
    Column("arrayconfig", VARCHAR(6), nullable=False),
    Column("numchan1", NUMBER(asdecimal=False), nullable=False),
    Column("numchan2", NUMBER(asdecimal=False), nullable=False),
    Column("numchan3", NUMBER(asdecimal=False), nullable=False),
    Column("numchan4", NUMBER(asdecimal=False), nullable=False),
    Column("inttime", NUMBER(asdecimal=False), nullable=False),
    Column("velocity1", NUMBER(asdecimal=False), nullable=False),
    Column("velocity2", NUMBER(asdecimal=False), nullable=False),
    Column("velocity3", NUMBER(asdecimal=False), nullable=False),
    Column("velocity4", NUMBER(asdecimal=False), nullable=False),
    Column("restfreq1", NUMBER(asdecimal=False), nullable=False),
    Column("restfreq2", NUMBER(asdecimal=False), nullable=False),
    Column("restfreq3", NUMBER(asdecimal=False), nullable=False),
    Column("restfreq4", NUMBER(asdecimal=False), nullable=False),
    Column("velsyscode", VARCHAR(10), nullable=False),
    Column("apoptions", VARCHAR(2), nullable=False),
    Column("dataselect1", NUMBER(asdecimal=False), nullable=False),
    Column("dataselect2", NUMBER(asdecimal=False), nullable=False),
    Column("dataselect3", NUMBER(asdecimal=False), nullable=False),
    Column("dataselect4", NUMBER(asdecimal=False), nullable=False),
    Column("chansep1", NUMBER(asdecimal=False), nullable=False),
    Column("chansep2", NUMBER(asdecimal=False), nullable=False),
    Column("chansep3", NUMBER(asdecimal=False), nullable=False),
    Column("chansep4", NUMBER(asdecimal=False), nullable=False),
    Column("oldtapenum", VARCHAR(8), nullable=False),
    Column("newtapenum", VARCHAR(8), nullable=False),
    Column("filenumber", NUMBER(asdecimal=False), nullable=False),
    Index("sumlist4_idx", "starttimeiat", "stoptimeiat"),
    Index("sumlist5_idx", "newtapenum", "filenumber"),
    Index("sumlist3_idx", "ra2000", "dec2000"),
    schema="E2EMGR",
)


t_validity_chk = Table(
    "validity_chk",
    metadata,
    Column("arch_file_id", NUMBER(asdecimal=False), server_default=text("0")),
    Column("file_type", VARCHAR(16), server_default=text("'none'")),
    Column("last_checked", DateTime, server_default=text("sysdate")),
    Column(
        "status",
        VARCHAR(16),
        server_default=text(
            """\
'none'
"""
        ),
    ),
    schema="E2EMGR",
)


class VlapipeImage(Base):
    __tablename__ = "vlapipe_image"
    __table_args__ = {"schema": "E2EMGR"}

    id = Column(VARCHAR(32), primary_key=True)
    obs_id = Column(VARCHAR(32), server_default=text("null"))
    archive_id = Column(VARCHAR(128), nullable=False)
    htm_id = Column(NUMBER(14, 0, False), server_default=text("0"))
    preview_id = Column(VARCHAR(128), nullable=False)
    access_format = Column(VARCHAR(32), nullable=False)
    access_estsize = Column(NUMBER(14, 0, False), server_default=text("0"))
    dataproduct_type = Column(VARCHAR(16), server_default=text("null"))
    dataproduct_subtype = Column(VARCHAR(32), server_default=text("null"))
    calib_level = Column(NUMBER(6, 0, False), server_default=text("0"))
    dataset_length = Column(NUMBER(14, 0, False), server_default=text("0"))
    im_nsubarrays = Column(NUMBER(8, 0, False), server_default=text("1"))
    im_naxes = Column(NUMBER(8, 0, False), server_default=text("0"))
    im_naxis1 = Column(NUMBER(8, 0, False), server_default=text("0"))
    im_naxis2 = Column(NUMBER(8, 0, False), server_default=text("0"))
    im_naxis3 = Column(NUMBER(8, 0, False), server_default=text("0"))
    im_naxis4 = Column(NUMBER(8, 0, False), server_default=text("0"))
    im_pixtype = Column(VARCHAR(16), server_default=text("null"))
    im_wcsaxes1 = Column(VARCHAR(16), server_default=text("null"))
    im_wcsaxes2 = Column(VARCHAR(16), server_default=text("null"))
    im_wcsaxes3 = Column(VARCHAR(16), server_default=text("null"))
    im_wcsaxes4 = Column(VARCHAR(16), server_default=text("null"))
    im_ra1 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_dec1 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_ra2 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_dec2 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_ra3 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_dec3 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_ra4 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_dec4 = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    im_scale = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    obs_title = Column(VARCHAR(128), server_default=text("null"))
    obs_creator_name = Column(VARCHAR(32), server_default=text("null"))
    obs_collection = Column(VARCHAR(32), server_default=text("null"))
    obs_creator_did = Column(VARCHAR(160), server_default=text("null"))
    obs_publisher_did = Column(VARCHAR(160), server_default=text("null"))
    obs_dataset_did = Column(VARCHAR(160), server_default=text("null"))
    obs_release_date = Column(VARCHAR(20), server_default=text("null"))
    obs_creation_date = Column(VARCHAR(20), server_default=text("null"))
    obs_creation_type = Column(VARCHAR(16), server_default=text("null"))
    facility_name = Column(VARCHAR(20), server_default=text("null"))
    instrument_name = Column(VARCHAR(20), server_default=text("null"))
    obs_bandpass = Column(VARCHAR(20), server_default=text("null"))
    obs_datasource = Column(VARCHAR(20), server_default=text("null"))
    proposal_id = Column(VARCHAR(20), server_default=text("null"))
    target_name = Column(VARCHAR(20), server_default=text("null"))
    target_class = Column(VARCHAR(20), server_default=text("null"))
    s_ra = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    s_dec = Column(NUMBER(asdecimal=False), index=True, server_default=text("0.0"))
    s_fov = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    s_region = Column(VARCHAR(128), server_default=text("null"))
    s_calib_status = Column(VARCHAR(32), server_default=text("'none'"))
    s_resolution = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    em_min = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    em_max = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    em_resolution = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    em_respower = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    t_min = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    t_max = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    t_exptime = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    t_resolution = Column(NUMBER(asdecimal=False), server_default=text("0.0"))
    o_ucd = Column(VARCHAR(20), server_default=text("null"))
    o_unit = Column(VARCHAR(32), server_default=text("'none'"))
    pol_states = Column(VARCHAR(20), server_default=text("null"))
    project_code = Column(VARCHAR(24), server_default=text("null"))
    obs_session = Column(VARCHAR(24), server_default=text("null"))
    file_id = Column(VARCHAR(64), server_default=text("null"))
    file_set_id = Column(VARCHAR(128), server_default=text("null"))
    file_subset_id = Column(VARCHAR(128), server_default=text("null"))
    dataset = Column(VARCHAR(128), server_default=text("null"))
    image_file = Column(VARCHAR(128), server_default=text("null"))
    obs_file_id = Column(VARCHAR(64), server_default=text("null"))
    cal_file_id = Column(VARCHAR(64), server_default=text("null"))
    root_dir = Column(VARCHAR(128), server_default=text("null"))
    file_dir = Column(
        VARCHAR(128),
        server_default=text(
            """\
null
"""
        ),
    )


t_weather = Table(
    "weather",
    metadata,
    Column("telescope", VARCHAR(8), nullable=False, index=True),
    Column("timestamp", NUMBER(12, 6, True), nullable=False, index=True, comment="MJD (decimal)"),
    Column("pressure", NUMBER(7, 2, True), nullable=False, comment="millibars"),
    Column("temp", NUMBER(7, 2, True), nullable=False, comment="degrees C"),
    Column("dewtemp", NUMBER(7, 2, True), nullable=False, comment="degrees C"),
    Column("windspeed", NUMBER(6, 2, True), nullable=False, comment="m/sec"),
    Column("winddir", NUMBER(6, 1, True), nullable=False, comment="degrees from North"),
    schema="E2EMGR",
)


class Wensscatalog(Base):
    __tablename__ = "wensscatalog"
    __table_args__ = {"schema": "E2EMGR"}

    wensscode = Column(VARCHAR(3), nullable=False)
    name = Column(VARCHAR(13), primary_key=True, nullable=False)
    raradb = Column(NUMBER(asdecimal=False), nullable=False)
    decradb = Column(NUMBER(asdecimal=False), nullable=False)
    raradj = Column(NUMBER(asdecimal=False), primary_key=True, nullable=False)
    decradj = Column(NUMBER(asdecimal=False), primary_key=True, nullable=False)
    srctype = Column(VARCHAR(1), nullable=False)
    warn = Column(VARCHAR(1), nullable=False)
    pflux = Column(NUMBER(asdecimal=False), nullable=False)
    flux = Column(NUMBER(asdecimal=False), nullable=False)
    majorax = Column(NUMBER(asdecimal=False), nullable=False)
    minorax = Column(NUMBER(asdecimal=False), nullable=False)
    posangle = Column(NUMBER(asdecimal=False), nullable=False)
    rms = Column(NUMBER(asdecimal=False), nullable=False)
    field = Column(VARCHAR(9), nullable=False)
    survey = Column(VARCHAR(10), nullable=False)
    rarad = Column(NUMBER(asdecimal=False))
    decrad = Column(NUMBER(asdecimal=False))
